package com.xkl.cdl.module.m_center_learn

import android.graphics.Typeface
import android.util.TypedValue
import android.view.LayoutInflater
import android.widget.TextView
import androidx.core.content.ContextCompat
import androidx.lifecycle.ViewModelProvider
import com.google.android.material.tabs.TabLayout
import com.google.android.material.tabs.TabLayoutMediator
import com.suliang.common.base.fragment.BaseFragmentVM
import com.suliang.common.util.LogUtil
import com.xkl.cdl.R
import com.xkl.cdl.adapter.ViewPagerAdapter
import com.xkl.cdl.databinding.FragmentLearnCenterBinding
import com.xkl.cdl.module.main.MainActivityViewModel

/**
 * 学习中心Fragment： 包含 科目
 */
class LearnCenterFragment : BaseFragmentVM<FragmentLearnCenterBinding, LearnCenterFragmentViewModel>() {

    companion object {
        @JvmStatic
        fun newInstance() = LearnCenterFragment()
    }

    override fun initViewModel(): LearnCenterFragmentViewModel {
        return ViewModelProvider(this)[LearnCenterFragmentViewModel::class.java].apply {
            this.mainActivityViewModel = ViewModelProvider(requireActivity())[MainActivityViewModel::class.java]
        }
    }

    override fun initFragment() {
        //初始化项目子tab和标题
        vm.initLearnCenterFragment()

        //必须先进行ViewPager2的适配器 设置
        binding.viewPager2.adapter = ViewPagerAdapter(this, vm.mProjectFragments)

        //注册 tabLayout 监听
        binding.tabLayout.addOnTabSelectedListener(object : TabLayout.OnTabSelectedListener {
            /** 选项卡被选中  */
            override fun onTabSelected(tab: TabLayout.Tab?) {
                tab?.customView?.let {
                    (it as TextView).apply {
                        setTextSize(TypedValue.COMPLEX_UNIT_DIP, 22f)
                        typeface = Typeface.defaultFromStyle(Typeface.BOLD)
                        setTextColor(ContextCompat.getColor(context, R.color.main_text_color))
                    }
                }
                //选中项恢复搜索框的数据
                tab?.run {


                }
                LogUtil.e("选中tab  ${tab?.position}")
            }
            /** 当选项卡被取消选中 */
            override fun onTabUnselected(tab: TabLayout.Tab?) {
                LogUtil.e("未选中tab ${tab?.position}")
                tab?.customView?.let {
                    (it as TextView).apply {
                        setTextSize(TypedValue.COMPLEX_UNIT_DIP, 16f)
                        typeface = Typeface.defaultFromStyle(Typeface.NORMAL)
                        setTextColor(ContextCompat.getColor(context, R.color.gray_2))
                    }
                }
            }
            /**当用户再次选择 已选中的Tab */
            override fun onTabReselected(tab: TabLayout.Tab?) {
            }
        })

        //TabLayout 与  ViewPager2 进行关联, 并进行tab设值
        TabLayoutMediator(binding.tabLayout, binding.viewPager2) { tab, position ->
            tab.setCustomView(layoutInflater.inflate(R.layout.textview_only,binding.tabLayout,false))
            tab.customView?.let {
                (it as TextView).setText(vm.mProjectTitles[position])
            }
        }.attach()



//        /** 搜索框 输入监听 */
//        binding.editTextSearch.setOnEditorActionListener { v, actionId, event ->
//            if (actionId == EditorInfo.IME_ACTION_SEARCH){
//                //隐藏键盘
//                KeyboardUtil.hideKeyboard(v)
//                //赋值，通知 子 Fragment 进行更新
//                v.text.toString()
//
//                true
//            }else {
//                false
//            }
//        }

    }

    override fun loadData() {


    }
}