package com.xkl.cdl.module.main

import android.os.Bundle
import androidx.lifecycle.ViewModelProvider
import com.suliang.common.base.activity.BaseActivityVM
import com.suliang.common.eventbus.LiveDataBus
import com.suliang.common.extension.loadFragment
import com.suliang.common.extension.showHideFragment
import com.suliang.common.util.LogUtil
import com.xkl.cdl.R
import com.xkl.cdl.databinding.ActivityMainBinding
import com.xkl.cdl.module.m_center_learn.LearnCenterFragment
import com.xkl.cdl.module.m_memo.MemoFragment
import com.xkl.cdl.module.m_my.MyFragment
import com.xkl.cdl.module.m_service_center.ServiceCenterFragment
import com.xkl.cdl.module.m_statics.StaticsFragment
import com.xkl.cdl.module.splash.SplashActivity

/**
 * 主界面、控制切换子Fragment
 * ViewModle 进行初始化加载数据，只有等所有数据加载完全才进行页面的切换，子Fragment使用的是懒加载，不用担心生命周期、性能的问题
 * @property mMemo MemoFragment
 * @property mStatistics StaticsFragment
 * @property mLearnCenter LearnCenterFragment
 * @property mServiceCenter ServiceCenterFragment
 * @property mMy MyFragment
 */
class MainActivity : BaseActivityVM<ActivityMainBinding, MainActivityViewModel>() {

    private val mMemo by lazy { MemoFragment.newInstance() }
    private val mStatistics by lazy { StaticsFragment.newInstance() }
    private val mLearnCenter by lazy { LearnCenterFragment.newInstance() }
    private val mServiceCenter by lazy { ServiceCenterFragment.newInstance() }
    private val mMy by lazy { MyFragment.newInstance() }

    override fun initViewModel(): MainActivityViewModel {
        return ViewModelProvider(this)[MainActivityViewModel::class.java]
    }


    override fun initActivity(savedInstanceState: Bundle?) {
        //加载Fragment并显示
        loadFragment(R.id.layout_container, -1, mMemo, mStatistics, mLearnCenter, mServiceCenter, mMy)
        //点击事件
        binding.layoutNavContainer.setOnCheckedChangeListener { group, checkedId ->
            when (checkedId) {
                R.id.nav_memo -> showHideFragment(mMemo)
                R.id.nav_statistics -> showHideFragment(mStatistics)
                R.id.nav_learnCenter -> showHideFragment(mLearnCenter)
                R.id.nav_serviceCenter -> showHideFragment(mServiceCenter)
                R.id.nav_my -> showHideFragment(mMy)
            }
        }
    }

    override fun loadData() {
        //加载初始化数据
        vm.loadInit().observe(this){
            binding.layoutNavContainer.check(R.id.nav_learnCenter)
        }
    }

}