package com.suliang.common.base

import android.graphics.Color
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.DialogFragment
import androidx.viewbinding.ViewBinding
import com.suliang.common.extension.initBinding
import android.graphics.drawable.ColorDrawable

import android.util.DisplayMetrics




/**
 * author suliang
 * create 2022/3/17 16:30
 * Describe:
 */
abstract class BaseDialogFragment<VB : ViewBinding> : DialogFragment() {
    private var _binding: VB? = null

    val binding: VB
        get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?
    ): View? {
        _binding = initBinding(inflater, container)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        requireDialog().apply {
            setCanceledOnTouchOutside(false)  // 点击屏幕不消失
            setCancelable(false)        //返回键不取消
        }
        initFragment()
    }

    override fun onStart() {
        super.onStart()
        if (isTransparent()){
            //设置背景透明
            dialog!!.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        }
    }


    abstract fun initFragment()

    /** 是否布局背景透明 */
    abstract fun isTransparent():Boolean
}