package com.suliang.common.base.viewmodel

import android.widget.Toast
import androidx.lifecycle.LifecycleOwner
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import com.suliang.common.base.ViewBehavior
import com.suliang.common.base.activity.ToastEvent
import com.suliang.common.util.LogUtil

/**
 * author suliang
 * create 2022/3/17 11:03
 * Describe:
 */
open class BaseViewModel : ViewModel(), ViewModelLifecycle, ViewBehavior {
    override fun onCreate(owner: LifecycleOwner) {
        super.onCreate(owner)
        LogUtil.i("${javaClass.name} onCreate() ")
    }

    override fun onStart(owner: LifecycleOwner) {
        super.onStart(owner)
        LogUtil.i("${javaClass.name} onStart() ")
    }

    override fun onResume(owner: LifecycleOwner) {
        super.onResume(owner)
        LogUtil.i("${javaClass.name} onResume() ")
    }

    override fun onPause(owner: LifecycleOwner) {
        super.onPause(owner)
        LogUtil.i("${javaClass.name} onPause() ")
    }

    override fun onStop(owner: LifecycleOwner) {
        super.onStop(owner)
        LogUtil.i("${javaClass.name} onStop() ")
    }

    override fun onDestroy(owner: LifecycleOwner) {
        super.onDestroy(owner)
        LogUtil.i("${javaClass.name} onDestroy() ")
    }

    override fun onCleared() {
        super.onCleared()
        LogUtil.i("${javaClass.name} onCleared() ")
    }

    var loadingEvent = MutableLiveData<Boolean>()
        private set

    var toastEvent = MutableLiveData<ToastEvent>()
        private set

    var pageEvent = MutableLiveData<Class<*>>()
        private set

    override fun showHideLoading(isShow: Boolean) {
        loadingEvent.postValue(isShow)
    }

    override fun showToast(msg: ToastEvent) {
        toastEvent.postValue(msg)
    }

    override fun startActivity(clazz: Class<*>) {
        pageEvent.postValue(clazz)
    }

}

