package com.suliang.common.eventbus

import androidx.lifecycle.MutableLiveData

/**
 * author suliang
 * create 2022/3/15 10:01
 * Describe: 事件总线，这条总线把任何类中的数据直接传递到activity 或是 fragment 上
 */
object LiveDataBus {

    private val bus = mutableMapOf<String,MutableLiveData<Any>>()

//    /**
//     * 注册订阅者
//     * @param key String key
//     * @param type Class<T> 类型
//     * @param sticky Boolean  是否需要粘性，true：需要  false:不需要
//     * @return MutableLiveData<T>
//     */
//    @Synchronized
//    fun <T> with(key: String, type: Class<T>, sticky: Boolean):  MutableLiveData<T>{
//        if (!bus.containsKey(key)) {
//            bus[key] = if (sticky) MutableLiveData<Any>() else NonStickyMutableLiveData<Any>()
//        }
//        return bus[key] as MutableLiveData<T>
//    }

//java使用传入泛型class, kotlin使用可直接传入泛型，不需要class类型

    @SuppressWarnings("UNCHECKED_CAST")
    @Synchronized
    fun <T> with(key:String) : MutableLiveData<T>{
        if (!bus.containsKey(key)){
            bus[key] = MutableLiveData()
        }
        return bus[key] as MutableLiveData<T>
    }
    @SuppressWarnings("UNCHECKED_CAST")
    @Synchronized
    fun <T> withNonSticky(key:String) : MutableLiveData<T>{
        if (!bus.containsKey(key)){
            bus[key] = NonStickyMutableLiveData()
        }
        return bus[key] as MutableLiveData<T>
    }



    @SuppressWarnings("UNCHECKED_CAST")
    @Synchronized
    fun <T> with(key:String,type: Class<T>) : MutableLiveData<T>{
        if (!bus.containsKey(key)){
            bus[key] = MutableLiveData()
        }
        return bus[key] as MutableLiveData<T>
    }
    @SuppressWarnings("UNCHECKED_CAST")
    @Synchronized
    fun <T> withNonSticky(key:String,type: Class<T>) : MutableLiveData<T>{
        if (!bus.containsKey(key)){
            bus[key] = NonStickyMutableLiveData()
        }
        return bus[key] as MutableLiveData<T>
    }

    fun remove(key:String){
        bus.remove(key)
    }


    fun clearAll(){
        bus.clear()
    }




}