package com.suliang.common.eventbus

import androidx.lifecycle.LifecycleOwner
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.Observer
import java.lang.Exception
import java.lang.NullPointerException
import java.lang.reflect.Method

/**
 * author suliang
 * create 2022/3/15 10:51
 * Describe:  非粘性LiveData
 */
class NonStickyMutableLiveData<T> : MutableLiveData<T>() {

    private var stickFlag : Boolean = false

    override fun observe(owner: LifecycleOwner, observer: Observer<in T>) {
        super.observe(owner, observer)
        if (!stickFlag){
            hook(observer)
            stickFlag = true
        }
    }

    private fun hook(observer: Observer<in T>) = try {
        //得到 mLastVersion
        //获取到LiveData的类中的mObserver对象
        // SafeIterableMap<Observer<? super T> , ObserverWrapper> mObservers
        val liveDataClass = LiveData::class.java
        val declaredField = liveDataClass.getDeclaredField("mObservers")
        declaredField.isAccessible = true
        //获取到这个成员变量的对象
        val mObserVersObject = declaredField.get(this)
        //得到map对应的class对象
        val mObserversClass = mObserVersObject.javaClass
        //获取到mObservers对象的get方法
        val get:Method = mObserversClass.getDeclaredMethod("get", Any::class.java)
        get.isAccessible = true
        //执行get方法，获取到对象
        val invokeEntry = get.invoke(mObserVersObject, observer)
        //定义一个空的对象
        val observerWrapper = if (invokeEntry is Map.Entry<*, *>) {
            invokeEntry.value
        } else throw NullPointerException("observerWrapper is null")

        //得到observerWrapper的对象，编译擦除问题会引起多态冲突，所以用getSupperClass
        //getClass 返回对应的当前正在运行是的类所对应的
        val mLastVersion = observerWrapper!!::class.java.superclass.getDeclaredField("mLastVersion")
        mLastVersion.isAccessible = true
        //得到mVersion
        val mVersion = liveDataClass.getDeclaredField("mVersion")
        mVersion.isAccessible = true
        //把mVersion数据填入到mLastVersion中
        val mVersionValue = mVersion.get(this)
        mLastVersion.set(observerWrapper,mVersionValue)

    }catch (e: Exception){
        e.printStackTrace()
    }


}