package com.suliang.common.extension

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.viewbinding.ViewBinding
import java.lang.reflect.ParameterizedType

/**
 * 扩展方法,获取到ViewBinding的子类VB实例，主要用于Activity
 * @receiver VB
 * @param inflater LayoutInflater
 * @param vbPosition Int 在超类泛型中的vb位置
 * @return VB
 */
@SuppressWarnings("UNCHECKED_CAST")
inline fun <VB : ViewBinding> Any.initBinding(inflater: LayoutInflater,vbPosition:Int = 0): VB {
    val vbClass =
        (javaClass.genericSuperclass as ParameterizedType).actualTypeArguments.filterIsInstance<Class<VB>>()
    val inflate = vbClass[vbPosition].getDeclaredMethod("inflate", LayoutInflater::class.java)
    return inflate.invoke(null, inflater) as VB
}

/**
 * 扩展方法，获取ViewBinding的实例 主要用于Fragment、ListItem等
 * @receiver Any
 * @param inflater LayoutInflater
 * @param container ViewGroup?
 * @param vbPosition Int
 * @return VB
 */
@SuppressWarnings("UNCHECKED_CAST")
inline fun <VB: ViewBinding> Any.initBinding(inflater: LayoutInflater, container:ViewGroup?,vbPosition:Int = 0):VB{
    val vbClass = (javaClass.genericSuperclass as ParameterizedType).actualTypeArguments.filterIsInstance<Class<VB>>()
    val inflate = vbClass[vbPosition].getDeclaredMethod("inflate",LayoutInflater::class.java,ViewGroup::class.java,Boolean::class.java)
    return inflate.invoke(null,inflater,container,false) as VB
}
