package com.suliang.common.util.image

import android.net.Uri
import android.widget.ImageView
import java.io.File

/**
 * author suliang
 * create 2022/3/11 16:10
 * Describe:  外部调用，图片加载库
 *
 * 顺序判断，自动限制，前面参数有值了，则后面的值无效,如果都没有值，则抛异常
 * url > file > drawableRes > uri
 *
 * https://blog.csdn.net/Coo123_/article/details/87950232
 * https://juejin.cn/post/6844903463134953479#heading-3
 * https://www.jianshu.com/p/19420b151507
 * https://blog.csdn.net/EthanCo/article/details/102587193
 * https://www.jianshu.com/p/e26130a93289
 *
 * 使用：
 * ImageLoader.loadImage(option)
 * ImageLoader.loadImage(view,source)
 * ImageLoaderOption ： 为加载的参数配置，必须要有上下文或者targetView，暂时没有设置listener监听和目标target，如果后期有使用，再在此类中进行配置，并在对应的strategy中进行实现
 *
 *
 *
 */
object ImageLoader {

    //具体实现的策略，外部可设置
    var mStrategy: IBaseLoaderStrategy? = GlideLoaderStrategy()


    fun loadImage(option: ImageLoaderOption) {
        mStrategy?.loadImage(option)
    }


    fun loadImage(imageView: ImageView, url: String) {
        loadImage(ImageLoaderOption().apply {
            this.url = url
            targetView = imageView
        })
    }

    fun loadImage(imageView: ImageView, file: File) {
        loadImage(ImageLoaderOption().apply {
            this.file = file
            targetView = imageView
        })
    }

    fun loadImage(imageView: ImageView, resourceId: Int) {
        loadImage(ImageLoaderOption().apply {
            this.resourceId = resourceId
            targetView = imageView
        })
    }

    fun loadImage(imageView: ImageView, uri: Uri) {
        loadImage(ImageLoaderOption().apply {
            this.uri = uri
            targetView = imageView
        })
    }


//    override fun clearMemoryCache() {
//        mStrategyBase.clearMemoryCache()
//    }
//
//    override fun clearDiskCache() {
//        mStrategyBase.clearDiskCache()
//    }

}