package com.suliang.common.util.image

import android.content.Context
import android.util.Log
import com.bumptech.glide.Glide
import com.bumptech.glide.GlideBuilder
import com.bumptech.glide.Registry
import com.bumptech.glide.annotation.GlideModule
import com.bumptech.glide.load.DecodeFormat
import com.bumptech.glide.load.engine.bitmap_recycle.LruBitmapPool
import com.bumptech.glide.load.engine.cache.InternalCacheDiskCacheFactory
import com.bumptech.glide.load.engine.cache.LruResourceCache
import com.bumptech.glide.load.engine.executor.GlideExecutor
import com.bumptech.glide.module.AppGlideModule
import com.bumptech.glide.module.LibraryGlideModule
import com.bumptech.glide.request.RequestOptions

/**
 * author suliang
 * create 2022/3/14 10:46
 * Describe:  Generated API 目前仅可以在 Application 模块内使用。这一限制可以让我们仅持有一份 Generated API，
 * 而不是各个 Library 和 Application 中均有自己定义出来的 Generated API。
 * 这一做法会让 Generated API 的调用更简单，并确保 Application 模块中 Generated API 调用的选项在各处行为一致。
 * 这一限制在接下来的版本中也许会被取消（以实验性或其他的方式给出）
 *
 * 与 Glide.with() 不同，诸如 fitCenter() 和 placeholder() 等选项在 Builder 中直接可用，并不需要再传入单独的 RequestOptions 对象
 *
 * GlideApp.with(fragment).load(myUrl).placeholder(R.drawable.placeholder).fitCenter().into(imageView);
 *
 *
 * https://blog.csdn.net/MldXTieJiang/article/details/109347774  全局配置
 */
@GlideModule
class MyGlideApp : AppGlideModule() {

    //已经迁移到 Glide v4 的 AppGlideModule 和 LibraryGlideModule ，你可以完全禁用清单解析。这样可以改善 Glide 的初始启动时间，并避免尝试解析元数据时的一些潜在问题
    override fun isManifestParsingEnabled(): Boolean {
        return false
    }

    override fun applyOptions(context: Context, builder: GlideBuilder) {
        builder.apply {

            val cacheSize = Runtime.getRuntime().maxMemory() / 8
            //设置Bitmap的缓存池
            setBitmapPool(LruBitmapPool(30))
            //设置内存缓存
            setMemoryCache(LruResourceCache(cacheSize))
            //设置磁盘缓存
            setDiskCache(InternalCacheDiskCacheFactory(context))
            //设置读取不在缓存中的资源的线程
            setResizeExecutor(GlideExecutor.newSourceExecutor())
            //设置读取磁盘缓存中的资源的线程
            setDiskCacheExecutor(GlideExecutor.newDiskCacheExecutor())
            //设置日子级别
            setLogLevel(Log.DEBUG)
            //设置全局选项
//            val apply = RequestOptions().apply {
//                format(DecodeFormat.PREFER_RGB_565)
//            }
//            setDefaultRequestOptions(apply)
        }
    }

}