package com.suliang.common.util.media

/**
 * author suliang
 * create 2022/3/8 16:21
 * Describe: MediaPlayer操作接口
 */
interface IMP {

    /**
     * 开始播放，从指定位置开始
     * @param url String 本地路径或网络url
     * @param position Int 指定位置 , 默认为0
     * @param listener 默认为空
     */
    fun play(url: String, position: Int = 0,listener: IMPListener? = null)

    /** 暂停播放 ,如果没有播放文件则会忽略*/
    fun pausePlay()

    /** 继续播放，如果没有播放文件则会忽略 */
    fun continuePlay()

    /** 停止播放，清空当前播放信息，如果没有播放文件信息，则忽略 */
    fun stopPlay()

    /** 释放销毁*/
    fun destroyPlay()

    /**
     *  拖动到指定位置播放
     * @param targetPosition Int
     */
    fun seekTo(targetPosition : Int)





    /**是否支持seekTo */
    fun seekToEnable() : Boolean

    /**
     * 获取播放路径
     * @return String
     */
    fun getPlayPath(): String

    /**
     * 获取总时间
     * @return Long
     */
    fun getDuration(): Int

    /**
     * 获取当前播放位置
     * @return Long
     */
    fun getCurrentPosition(): Int

    /** 是否播放中 */
    fun isPlaying(): Boolean

    /**
     * 获取当前播放状态
     * @return MediaPlayerStatus
     */
    fun getMediaState(): EMediaState

    /** 添加监听 */
    fun addPlayListener(listener: IMPListener)

    /** 移除监听 */
    fun removePlayListener()

}