package com.suliang.common.util.os

import android.app.Activity
import android.app.AppOpsManager
import android.content.Context
import android.content.Intent
import android.net.Uri
import android.os.Binder
import android.provider.Settings
import java.lang.Exception

/**
 * author suliang
 * create 2022/3/8 15:52
 * Describe:  悬浮框工具
 */
class FloatingWindowUtil {
    /**
     * 检查悬浮框权限
     * @param context Context 上下文
     * @return Boolean  是否开启了悬浮框权限
     */
    fun checkOverLayerPermission(context: Context): Boolean {
        return if (VersionUtil.versionMorLater()) Settings.canDrawOverlays(context) else checkOp(context, 24)
    }

    private fun checkOp(context: Context, op: Int): Boolean {
        val manager = context.getSystemService(Context.APP_OPS_SERVICE) as AppOpsManager
        try {
            val method =
                AppOpsManager::class.java.getDeclaredMethod("checkOp", Int::class.javaPrimitiveType, Int::class.javaPrimitiveType, String::class.java)
            return AppOpsManager.MODE_ALLOWED == method.invoke(manager, op, Binder.getCallingUid(), context.packageName) as Int
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return false
    }

    /**
     * 跳转打开悬浮窗权限设置界面
     * @param activity Activity
     */
    fun applyOverLayerPermission(activity: Activity) {
        if (VersionUtil.versionMorLater()) {
            val intent = Intent()
            intent.action = Settings.ACTION_MANAGE_OVERLAY_PERMISSION
            intent.data = Uri.parse("package:" + activity.packageName)
            activity.startActivityForResult(intent, 0)
        } else {
            val intent = Intent()
            intent.action = Settings.ACTION_MANAGE_OVERLAY_PERMISSION
            intent.data = Uri.fromParts("package", activity.packageName, null)
            activity.startActivityForResult(intent, 0)
        }
    }

}