package com.suliang.common.util.os

import android.annotation.TargetApi
import android.app.Activity
import android.content.Context
import android.content.res.Resources
import android.os.Build
import android.util.DisplayMetrics
import android.view.ViewConfiguration
import android.view.WindowManager
import com.suliang.common.util.AppGlobals
import com.suliang.common.util.LogUtil
import java.lang.Exception

/**
 * author suliang
 * create 2022/3/8 15:41
 * Describe: 屏幕工具
 */
object ScreenUtil {

    private var screenWidth = 0
    private var screenHeight = 0
    /**
     * 获取屏幕宽度
     * @return
     */
    fun getScreenWidth(): Int {
        if (screenWidth == 0) {
            screenWidth = AppGlobals.application.resources.displayMetrics.widthPixels
        }
        return screenWidth
    }

    /**
     * 获取屏幕高度
     * @return
     */
    fun getScreenHeight(): Int {
        if (screenHeight == 0) {
            screenHeight = AppGlobals.application.resources.displayMetrics.heightPixels
        }
        return screenHeight
    }

    /** 获取状态栏高度  */
    fun getStatusBarHeight(): Int {
        var statusBarHeight = -1
        val resources: Resources = AppGlobals.application.resources
        //获取status_bar_height的资源Id
        val resourceId = resources.getIdentifier("status_bar_height", "dimen", "android")
        if (resourceId > 0) {
            //根据资源Id获取相应的尺寸
            statusBarHeight = resources.getDimensionPixelSize(resourceId)
        }
        LogUtil.d(" 状态栏高度 navigationBarHeight = $statusBarHeight")
        return statusBarHeight
    }

    /**
     * 获取虚拟按键的高度
     */
    fun getNavigationBarHeight(): Int {
        var result = 0
        if (hasNavBar(AppGlobals.application)) {
            val res: Resources = AppGlobals.application.resources
            val resourceId = res.getIdentifier("navigation_bar_height", "dimen", "android")
            if (resourceId > 0) {
                result = res.getDimensionPixelSize(resourceId)
            }
        }
        LogUtil.d(" 虚拟按键高度 navigationBarHeight = $result")
        return result
    }

    /**
     * 检查是否存在虚拟按键栏
     */
    @TargetApi(Build.VERSION_CODES.ICE_CREAM_SANDWICH)
    private fun hasNavBar(context: Context): Boolean {
        val res = context.resources
        val resourceId = res.getIdentifier("config_showNavigationBar", "bool", "android")
        return if (resourceId != 0) {
            var hasNav = res.getBoolean(resourceId)
            val sNavBarOverride = getNavBarOverride()
            if ("1" == sNavBarOverride) {
                hasNav = false
            } else if ("0" == sNavBarOverride) {
                hasNav = true
            }
            hasNav
        } else {
            !ViewConfiguration.get(context).hasPermanentMenuKey()
        }
    }

    /**
     * 判断虚拟按键栏是否重写
     */
    private fun getNavBarOverride(): String? {
        var sNavBarOverride: String? = null
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            try {
                val c = Class.forName("android.os.SystemProperties")
                val m = c.getDeclaredMethod("get", String::class.java)
                m.isAccessible = true
                sNavBarOverride = m.invoke(null, "qemu.hw.mainkeys") as String
            } catch (e: Exception) {
                e.printStackTrace()
            }
        }
        return sNavBarOverride
    }

    /**
     * dp2px
     */
    fun dp2px(dpValue: Float): Int {
        val scale = AppGlobals.application.resources.displayMetrics.density
        return (dpValue * scale + 0.5f).toInt()
    }

    /**
     * 屏幕变暗  alpha 0.3
     * @param activity Activity
     */
    fun lightOff(activity: Activity) {
        val lp = activity.window.attributes
        lp.alpha = 0.3f
        activity.window.attributes = lp
    }

    /**
     * 屏幕变亮  alpha 1
     * @param activity Activity
     */
    fun lightOn(activity: Activity) {
        val lp = activity.window.attributes
        lp.alpha = 1f
        activity.window.attributes = lp
    }
}