package com.suliang.common.widget

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Color
import android.graphics.Rect
import android.graphics.drawable.Drawable
import android.util.AttributeSet
import android.view.MotionEvent
import android.view.inputmethod.EditorInfo
import androidx.appcompat.widget.AppCompatEditText
import androidx.core.content.res.ResourcesCompat
import com.suliang.common.R
import com.suliang.common.util.os.KeyboardUtil

/**
 * author suliang
 * create 2022/3/16 18:07
 * Describe: 带关闭按钮的输入框  ： 左侧为搜索图标， 右侧为删除图标 ,需自动设置监听改变
 */

@SuppressLint("UseCompatLoadingForDrawables")
class InputSearchEditText @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null,
                                                    defStyleAttr: Int = 0) :
    AppCompatEditText(context, attrs, defStyleAttr) {

    private val clearRect by lazy { Rect() }
    private var ic_delete_src: Int = 0
    private var ic_delete_color: Int = 0
    private var ic_search_src: Int = 0
    private var ic_search_color: Int = 0

    private var drawableStart: Drawable? = null
    private var drawableEnd: Drawable? = null

    init {
        attrs?.let {
            context.obtainStyledAttributes(attrs, R.styleable.InputSearchEditText, defStyleAttr, 0).let {
                ic_search_src = it.getResourceId(R.styleable.InputSearchEditText_ic_search_src, R.drawable.ic_search)
                ic_search_color =
                    it.getColor(R.styleable.InputSearchEditText_ic_search_color, Color.parseColor("#8A8A8A"))
                ic_delete_color =
                    it.getColor(R.styleable.InputSearchEditText_ic_delete_color, Color.parseColor("#8A8A8A"))
                ic_delete_src = it.getColor(R.styleable.InputSearchEditText_ic_delete_src, R.drawable.ic_delete)
                it.recycle()
                drawableStart = resources.getDrawable(ic_search_src, null).apply {
                    setTint(ic_search_color)
                }
                setCompoundDrawablesWithIntrinsicBounds(drawableStart, null, null, null)
                drawableEnd = resources.getDrawable(ic_delete_src, null).apply {
                    setTint(ic_delete_color)
                }
            }
        }
    }

    override fun onSizeChanged(w: Int, h: Int, oldw: Int, oldh: Int) {
        super.onSizeChanged(w, h, oldw, oldh)
        //计算删除按钮所在的矩形区域
        clearRect.apply {
            left = w - paddingRight - w.coerceAtMost(h)
            top = paddingTop
            right = w - paddingRight
            bottom = w.coerceAtLeast(h)
        }
    }

    override fun onFocusChanged(focused: Boolean, direction: Int, previouslyFocusedRect: Rect?) {
        super.onFocusChanged(focused, direction, previouslyFocusedRect)
        checkEditFocus(focused)
    }

    /** 根据焦点改变，显示对应的图标内容
     * @param focused Boolean 有焦点为true 否则false
     */
    @SuppressLint("UseCompatLoadingForDrawables")
    private fun checkEditFocus(focused: Boolean) {
        if (text.isNullOrEmpty() || !focused) {      //如果没有内容 或者没有焦点，则设置搜索图标
            setCompoundDrawablesWithIntrinsicBounds(drawableStart, null, null, null)
        } else {
            setCompoundDrawablesRelativeWithIntrinsicBounds(drawableStart, null, drawableEnd, null)
        }
    }

    override fun onTextChanged(text: CharSequence?, start: Int, lengthBefore: Int, lengthAfter: Int) {
        super.onTextChanged(text, start, lengthBefore, lengthAfter)
        //时刻监听
        checkEditFocus(true)
    }

    @SuppressLint("ClickableViewAccessibility")
    override fun onTouchEvent(event: MotionEvent): Boolean {
        if (event.action == MotionEvent.ACTION_DOWN && isFocused && clearRect.contains(event.x.toInt(),event.y.toInt()) && text.isNullOrEmpty()){
                setText("")
                return true
        }
        return super.onTouchEvent(event)
    }

    override fun onEditorAction(actionCode: Int) {
        if (actionCode == EditorInfo.IME_ACTION_SEARCH){
            KeyboardUtil.hideKeyboard(this)
        }
        super.onEditorAction(actionCode)
    }




}